Ackermann class

Ackermann with memoization and safety.

Constructors

Ackermann()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearCache() → void
compute(int m, int n) BigInt
Compute A(m,n) with memoization.
describe(int m, int n) String
Describe A(m,n) safely.
getCacheSize() int