ComplexOperationX<T extends Complex> extension

on
  • T

Methods

abs() num

Available on T, provided by the ComplexOperationX extension

ceil() num

Available on T, provided by the ComplexOperationX extension

Returns the ceiling of the real portion of this complex number.
ceilToComplex() Complex

Available on T, provided by the ComplexOperationX extension

Returns the complex number with both parts ceiled to integers.
clamp(dynamic lowerLimit, dynamic upperLimit) → dynamic

Available on T, provided by the ComplexOperationX extension

Returns a Complex number whose real portion has been clamped to within lowerLimit and upperLimit and whose imaginary portion is the same as the imaginary value in this Complex number.
clampMagnitude(num min, num max) Complex

Available on T, provided by the ComplexOperationX extension

Clamps this complex number's magnitude between the specified minimum and maximum values.
distanceTo(Complex other) Complex

Available on T, provided by the ComplexOperationX extension

Returns the distance between this complex number and another in the complex plane.
exp() Complex

Available on T, provided by the ComplexOperationX extension

Returns a new complex number representing the exponential of this number.
flipPhase() Complex

Available on T, provided by the ComplexOperationX extension

Returns a complex number with the same magnitude but opposite phase.
floor() int

Available on T, provided by the ComplexOperationX extension

Returns the floor of the real portion of this complex number.
floorToComplex() Complex

Available on T, provided by the ComplexOperationX extension

Returns the complex number with both parts floored to integers.
isWithinCircle(Complex center, num radius) bool

Available on T, provided by the ComplexOperationX extension

Checks if this complex number lies within a circle centered at the given point with the specified radius.
ln() Complex

Available on T, provided by the ComplexOperationX extension

Returns a new complex number representing the natural logarithm (base e) of this number.
log() Complex

Available on T, provided by the ComplexOperationX extension

Calculates the natural logarithm of the complex number.
log10() Complex

Available on T, provided by the ComplexOperationX extension

Calculates the base-10 logarithm of the complex number.
log2() Complex

Available on T, provided by the ComplexOperationX extension

Calculates the base-2 logarithm of the complex number.
logBase(num base) Complex

Available on T, provided by the ComplexOperationX extension

Calculates the logarithm of the complex number with an arbitrary base.
nthRoot(num n, {bool allRoots = false}) → dynamic

Available on T, provided by the ComplexOperationX extension

Computes the n-th roots of the complex number represented by this object.
pow(dynamic x) Complex

Available on T, provided by the ComplexOperationX extension

Returns a new complex number representing this number raised to the power of exponent.
power(dynamic exponent) Complex

Available on T, provided by the ComplexOperationX extension

Returns a new complex number representing this number raised to the power of exponent.
remainder(dynamic divisor) num

Available on T, provided by the ComplexOperationX extension

The remainder method operates on the real portion of this Complex number only.
rotate(num angleRadians) Complex

Available on T, provided by the ComplexOperationX extension

Rotates this complex number by the specified angle in radians.
round() int

Available on T, provided by the ComplexOperationX extension

Returns the integer closest to the real portion of this complex number.
roundTo({int? decimals, bool asComplex = true}) → dynamic

Available on T, provided by the ComplexOperationX extension

Returns the rounded value of this complex number.
sqrt() Complex

Available on T, provided by the ComplexOperationX extension

Returns a new complex number representing the square root of this number.
sqrt1z() Complex

Available on T, provided by the ComplexOperationX extension

toMatrix() List<List<num>>

Available on T, provided by the ComplexOperationX extension

Returns the 2x2 matrix representation of this complex number
truncate() int

Available on T, provided by the ComplexOperationX extension

Returns the real portion of this complex number, truncated to an Integer.
truncateToComplex() Complex

Available on T, provided by the ComplexOperationX extension

Returns the complex number with both parts truncated to integers.

Static Methods

lerp(Complex a, Complex b, num t) Complex

Available on T, provided by the ComplexOperationX extension

Linearly interpolates between two complex numbers.
max(Complex a, Complex b) Complex

Available on T, provided by the ComplexOperationX extension

Returns the maximum of two complex numbers based on their magnitudes.
min(Complex a, Complex b) Complex

Available on T, provided by the ComplexOperationX extension

Returns the minimum of two complex numbers based on their magnitudes.