ExtString extension

on

Methods

allInCaps() String

Available on String, provided by the ExtString extension

Converts all the characters of the string to uppercase.
capitalize({bool all = true}) String

Available on String, provided by the ExtString extension

Capitalizes the first letter of each word in the string if all is set to true. Otherwise, it only capitalizes the first letter of the string.
containsNumber() bool

Available on String, provided by the ExtString extension

Checks if the string contains a number.
containsSymbol() bool

Available on String, provided by the ExtString extension

Checks if the string contains any of the special symbols.
containsUpperMixCaseLetter() bool

Available on String, provided by the ExtString extension

Checks if the string contains both uppercase and lowercase letters.
extractAlphanumeric({bool excludeSymbols = false}) String

Available on String, provided by the ExtString extension

Extracts all alphanumeric characters, including accents and symbols, from the string and returns them as a single string.
extractCustomPattern(String pattern, {bool unicode = true}) List<String>

Available on String, provided by the ExtString extension

Extracts custom patterns from the string.
extractEmails() List<String>

Available on String, provided by the ExtString extension

Extracts email addresses from the string.
extractLetters({bool excludeSymbols = false}) String

Available on String, provided by the ExtString extension

Extracts all letters, including accents and symbols, from the string.
extractLettersList({bool excludeSymbols = false}) List<String>

Available on String, provided by the ExtString extension

Extracts all letters, including accents and symbols, from the string and returns them as a list.
extractNumbers({bool excludeDecimalsAndSymbols = false}) String

Available on String, provided by the ExtString extension

Extracts all numbers, including decimals and currency symbols, from the string and returns them as a single string.
extractNumbersList({bool excludeDecimalsAndSymbols = false}) List<String>

Available on String, provided by the ExtString extension

Extracts all numbers, including decimals and currency symbols, from the string and returns them as a list.
extractUrls() List<String>

Available on String, provided by the ExtString extension

Extracts URLs from the string.
extractWords({bool excludeNumbers = false}) List<String>

Available on String, provided by the ExtString extension

Extracts words from the string, including those with accents and numbers.
isAlpha() bool

Available on String, provided by the ExtString extension

Checks if the string characters are alphabetic letter(s) (A-Z, a-z).
isAlphaNumeric() bool

Available on String, provided by the ExtString extension

Checks if the provided character input is alphanumeric (A-Z, a-z, 0-9).
isDigit() bool

Available on String, provided by the ExtString extension

Checks if the string characters are a digit(s) (0-9).
isValidEmail() bool

Available on String, provided by the ExtString extension

Checks if the string is a valid email format.
isValidName() bool

Available on String, provided by the ExtString extension

Checks if the string is a valid name. A valid name shouldn't contain any symbols or special characters.
isValidNumeric() bool

Available on String, provided by the ExtString extension

Checks if the string is a valid numeric character.
isValidPassword([int passwordLength = 6]) bool

Available on String, provided by the ExtString extension

Checks if the string is a valid password. A valid password should have at least one uppercase letter, one lowercase letter, one number, one special character, and should be at least 6 characters long.
isValidPhone({int length = 10}) bool

Available on String, provided by the ExtString extension

Checks if the string is a valid phone number format of a specified length.
passwordValidationMessage([int passwordLength = 6]) String?

Available on String, provided by the ExtString extension

Returns an error message if the password is invalid. Returns null if the password is valid.
removeSpecialCharacters({bool alphabets = true, bool numeric = true, String replaceWith = ''}) String

Available on String, provided by the ExtString extension

Removes special characters from the string based on the provided criteria.
replaceCharactersInList(List<String> originalList, Map<String, String> replacements) List<String>

Available on String, provided by the ExtString extension

Replace characters from a list of strings that