Geometry class abstract

An abstract class representing a general geometric shape.

Implementers

Constructors

Geometry(String name)
Constructor for the Geometry class.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the geometric shape.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

area() num
Calculates the area of the geometric shape.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
perimeter() num
Calculates the perimeter of the geometric shape.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited