HybridCalculus class

A hybrid calculus class that bridges symbolic and numerical methods.

This class provides methods to evaluate symbolic expressions using numerical techniques and to compare the results of symbolic and numerical calculations for validation purposes.

Constructors

HybridCalculus()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compareResults(Expression expr, String variable, num at, {num a = 0, num b = 1}) Map<String, dynamic>
Compares symbolic and numerical results for validation.
evaluateDerivative(Expression expr, String variable, num at) num
Evaluates the derivative of a symbolic expression numerically.
evaluateIntegral(Expression expr, String variable, num a, num b) num
Evaluates the integral of a symbolic expression numerically.