IsoscelesTrapezoid class

A class representing an Isosceles Trapezoid in 2D space.

Inheritance

Constructors

IsoscelesTrapezoid(num base1, num base2, num side, num height)
Constructs an Isosceles Trapezoid with the given base1, base2, side, and height.
IsoscelesTrapezoid.from({num? base1, num? base2, num? side, num? height})
Named constructor to create an Isosceles Trapezoid from various parameters.

Properties

base1 num
The lengths of the parallel sides (bases) of the Trapezoid.
finalinherited
base2 num
The lengths of the parallel sides (bases) of the Trapezoid.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height num
The height of the Trapezoid.
finalinherited
name String
The name of the geometric shape.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
side1 num
The lengths of the non-parallel sides of the Trapezoid.
finalinherited
side2 num
The lengths of the non-parallel sides of the Trapezoid.
finalinherited

Methods

angles() List
Calculates the angles between the sides of the Trapezoid.
inherited
area() double
Calculates the area of the Trapezoid.
inherited
diagonals() List
Calculates the lengths of the diagonals of the Trapezoid.
inherited
median() double
Calculates the length of the median of the Trapezoid.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
perimeter() double
Calculates the perimeter of the Trapezoid.
inherited
sideLengthB(double angleAlpha, double angleBeta) double
Calculates the length of side b of the Trapezoid.
inherited
sideLengthC(double angleAlpha) double
Calculates the length of side c of the Trapezoid.
inherited
sideLengthD(double angleBeta) double
Calculates the length of side d of the Trapezoid.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited