b property
Expression
get
b
The second coefficient of the equation in the form f(x) = ab + b.
Implementation
Expression get b => coefficients[1];
The second coefficient of the equation in the form f(x) = ab + b.
Expression get b => coefficients[1];