MatrixElementIterator class

A custom iterator for traversing the elements of a Matrix in row-major order.

This iterator can be used to iterate through individual elements of a matrix, allowing you to access each element one by one in a linear fashion.

Implemented types
Available extensions

Constructors

MatrixElementIterator(Matrix _matrix)
Constructs a new MatrixElementIterator instance.

Properties

current → dynamic
Returns the current element of the matrix.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJSIterator JSIterator<T>

Available on Iterator<T>, provided by the IteratorToJSIterator extension

A JSIterator wrapper that proxies to the Dart iterator API.
no setter

Methods

moveNext() bool
Advances the iterator to the next element.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited