conjugateTranspose method
Returns the conjugate transpose (also known as the Hermitian transpose) of the matrix. The conjugate transpose is obtained by first computing the conjugate of the matrix and then transposing it.
If the matrix has complex elements, the conjugate transpose is computed by taking the complex conjugate of each element and transposing the resulting matrix.
Example:
var A = Matrix('1+2i 3-4i; 5+6i 7-8i');
var B = A.conjugateTranspose();
Returns a new Matrix object containing the conjugate transpose.
Implementation
Matrix conjugateTranspose() {
return conjugate().transpose();
}