evaluate method
Evaluates the expression for a given value of x.
This method returns the value of the expression when evaluated at x.
If x is not provided, the method should return the general form of the
expression or a representative value.
Returns:
- A
dynamicrepresenting the evaluated value of the expression.
Implementation
@override
dynamic evaluate([dynamic arg]) {
var obj = object.evaluate(arg);
if (obj == null) return null;
return _getMember(obj, property.name);
}