isNotComputedYet property
bool
get
isNotComputedYet
Check if the memoized value is not computed yet.
Implementation
bool get isNotComputedYet => _status == MemoizedStatus.notComputed;
Check if the memoized value is not computed yet.
bool get isNotComputedYet => _status == MemoizedStatus.notComputed;