ODEResult class

Result of an ODE solver.

Constructors

ODEResult({required List<num> t, required List y, required int steps, required bool success, String message = ''})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Additional message or error description.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps int
Number of steps taken.
final
success bool
Whether the solver succeeded.
final
t List<num>
Time points.
final
y List
Solution values at each time point. For single ODE: List<num> For systems: List<List<num>> where each inner list is [y1, y2, ..., yn] at time ti
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited