Regression class

Regression analysis methods.

Constructors

Regression()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

elasticNet(Matrix X, dynamic y, {double alpha = 1.0, double l1Ratio = 0.5, int maxIter = 1000, double tol = 1e-4}) RegressionResult
Elastic Net regression (L1 and L2 regularization). l1Ratio = 1.0 is Lasso, 0.0 is Ridge.
lasso(Matrix X, dynamic y, {double alpha = 1.0, int maxIter = 1000, double tol = 1e-4}) RegressionResult
Lasso regression (L1 regularization) using Coordinate Descent.
linear(dynamic x, dynamic y) RegressionResult
Simple linear regression (y = a + bx).
logistic(Matrix X, dynamic y, {int maxIter = 100, double learningRate = 0.01}) RegressionResult
Logistic regression for binary classification.
multipleLinear(Matrix X, dynamic y) RegressionResult
Multiple linear regression.
polynomial(dynamic x, dynamic y, int degree) RegressionResult
Polynomial regression.
ridge(Matrix X, dynamic y, {double alpha = 1.0}) RegressionResult
Ridge regression (L2 regularization).