RootFinding class

A collection of root-finding algorithms for non-linear equations.

Constructors

RootFinding()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bisection(Function f, num a, num b, {double tolerance = 1e-6, int maxIter = 100}) num
Finds a root of a continuous function f in the interval [a, b] using the Bisection method.
brent(Function f, num a, num b, {double tolerance = 1e-6, int maxIter = 100}) num
Finds a root using Brent's method.
falsePosition(Function f, num a, num b, {double tolerance = 1e-6, int maxIter = 100}) num
Finds a root using the False Position (Regula Falsi) method.
fixedPoint(Function g, num x0, {double tolerance = 1e-6, int maxIter = 100}) num
Finds a fixed point x such that g(x) = x.
muller(Function f, dynamic x0, dynamic x1, dynamic x2, {double tolerance = 1e-6, int maxIter = 100}) Complex
Finds a complex root using Muller's method.
newtonRaphson(Function f, Function df, num x0, {double tolerance = 1e-6, int maxIter = 100}) num
Finds a root using the Newton-Raphson method.
secant(Function f, num x0, num x1, {double tolerance = 1e-6, int maxIter = 100}) num
Finds a root using the Secant method.