StudentTDistribution class

Student's t-distribution.

Constructors

StudentTDistribution(int degreesOfFreedom)

Properties

degreesOfFreedom int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cdf(num x) num
Cumulative distribution function.
mean() num
Mean of the distribution.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pdf(num x) num
Probability density function (continuous) or mass function (discrete).
quantile(num p) num
Quantile function (inverse CDF).
sample() num
Generate a single random sample.
samples(int n) List<num>
Generate multiple random samples.
inherited
stdDev() num
Standard deviation of the distribution.
inherited
toString() String
A string representation of this object.
inherited
variance() num
Variance of the distribution.

Operators

operator ==(Object other) bool
The equality operator.
inherited