SymbolicBusyBeaver class

Inheritance

Constructors

SymbolicBusyBeaver(int n)

Properties

hashCode int
The hash code for this object.
no setterinherited
isComputable bool
Whether this LargeNumber is likely computable within limits.
no setteroverride
n int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDescription() String
Human description (multi-line allowed).
override
toExpression() String
Short expression form.
override
toString() String
A string representation of this object.
inherited
tryCompute() BigInt?
Attempt to compute a BigInt value, or return null if symbolic.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited