standardError method
dynamic
standardError()
Compute standard error of residuals, which is the standard deviation divided by the square root of the number of observations.
Implementation
dynamic standardError() {
return standardDeviation() / math.sqrt(A.rowCount);
}