ComputeConfig class
=============================== CONFIGURATION
Configuration for compute limits and verbosity.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- maxBitLength ↔ int
-
Maximum bit length allowed for BigInt results.
getter/setter pair
- maxIterations ↔ int
-
Maximum iterations used when converting BigInt -> int.
getter/setter pair
- useSymbolicFallback ↔ bool
-
When true, hyperop suggests symbolic fallback for huge requests.
getter/setter pair
- verboseMode ↔ bool
-
Print verbose diagnostics when true.
getter/setter pair
Static Methods
-
setAggressive(
) → void - Aggressive limits.
-
setConservative(
) → void - Conservative limits.