ExtString extension
- on
Methods
-
allInCaps(
) → String - Converts all the characters of the string to uppercase.
-
capitalize(
{bool all = true}) → String -
Available on String, provided by the ExtString extension
Capitalizes the first letter of each word in the string ifallis set to true. Otherwise, it only capitalizes the first letter of the string. -
containsNumber(
) → bool - Checks if the string contains a number.
-
containsSymbol(
) → bool - Checks if the string contains any of the special symbols.
-
containsUpperMixCaseLetter(
) → bool - Checks if the string contains both uppercase and lowercase letters.
-
extractAlphanumeric(
{bool excludeSymbols = false}) → String - Extracts all alphanumeric characters, including accents and symbols, from the string and returns them as a single string.
-
extractCustomPattern(
String pattern, {bool unicode = true}) → List< String> - Extracts custom patterns from the string.
-
extractEmails(
) → List< String> - Extracts email addresses from the string.
-
extractLetters(
{bool excludeSymbols = false}) → String - Extracts all letters, including accents and symbols, from the string.
-
extractLettersList(
{bool excludeSymbols = false}) → List< String> - Extracts all letters, including accents and symbols, from the string and returns them as a list.
-
extractNumbers(
{bool excludeDecimalsAndSymbols = false}) → String - Extracts all numbers, including decimals and currency symbols, from the string and returns them as a single string.
-
extractNumbersList(
{bool excludeDecimalsAndSymbols = false}) → List< String> - Extracts all numbers, including decimals and currency symbols, from the string and returns them as a list.
-
extractUrls(
) → List< String> - Extracts URLs from the string.
-
extractWords(
{bool excludeNumbers = false}) → List< String> - Extracts words from the string, including those with accents and numbers.
-
isAlpha(
) → bool - Checks if the string characters are alphabetic letter(s) (A-Z, a-z).
-
isAlphaNumeric(
) → bool -
Available on String, provided by the ExtString extension
Checks if the provided characterinputis alphanumeric (A-Z, a-z, 0-9). -
isDigit(
) → bool - Checks if the string characters are a digit(s) (0-9).
-
isValidEmail(
) → bool - Checks if the string is a valid email format.
-
isValidName(
) → bool - Checks if the string is a valid name. A valid name shouldn't contain any symbols or special characters.
-
isValidNumeric(
) → bool - Checks if the string is a valid numeric character.
-
isValidPassword(
[int passwordLength = 6]) → bool - Checks if the string is a valid password. A valid password should have at least one uppercase letter, one lowercase letter, one number, one special character, and should be at least 6 characters long.
-
isValidPhone(
{int length = 10}) → bool -
Available on String, provided by the ExtString extension
Checks if the string is a valid phone number format of a specifiedlength. -
passwordValidationMessage(
[int passwordLength = 6]) → String? -
Available on String, provided by the ExtString extension
Returns an error message if the password is invalid. Returnsnullif the password is valid. -
removeSpecialCharacters(
{bool alphabets = true, bool numeric = true, String replaceWith = ''}) → String - Removes special characters from the string based on the provided criteria.
-
replaceCharactersInList(
List< String> originalList, Map<String, String> replacements) → List<String> - Replace characters from a list of strings that