IntegrationByPartsStrategy class
Integration by Parts: ∫u dv = uv - ∫v du Uses ILATE heuristic: Inverse, Logarithmic, Algebraic, Trigonometric, Exponential
- Implemented types
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
tryIntegrate(
Expression expr, Variable v) → Expression? -
Attempts to integrate the expression
Returns null if this strategy cannot handle the expression
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited