MethodType enum
An enumeration of interpolation methods.
Values
- linear → const MethodType
-
Linear interpolation between two data points.
- nearest → const MethodType
-
Uses the nearest data point as the interpolated value.
- previous → const MethodType
-
Uses the previous data point as the interpolated value.
- next → const MethodType
-
Uses the next data point as the interpolated value.
- quadratic → const MethodType
-
Uses a quadratic polynomial to interpolate between data points.
- cubic → const MethodType
-
Uses a cubic polynomial to interpolate between data points.
- newton → const MethodType
-
Uses Newton's divided difference formula for interpolation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MethodType> - A constant List of the values in this enum, in order of their declaration.