NonlinearSystemResult class
Result of a nonlinear system solver.
Constructors
- NonlinearSystemResult({required Matrix solution, required int iterations, required bool converged, String message = ''})
Properties
- converged → bool
-
Whether the solver converged.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iterations → int
-
Number of iterations performed.
final
- message → String
-
Additional message or error description.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- solution → Matrix
-
The solution vector.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited